# Changelog

## [0.2.0](https://github.com/tkk2112/pyproject_aliases/compare/v0.1.0...v0.2.0) (2025-03-30)


### ⚠ BREAKING CHANGES

* add "dir marching" to locate pyproject if not given

### Features

* add "dir marching" to locate pyproject if not given ([e23e1c9](https://github.com/tkk2112/pyproject_aliases/commit/e23e1c944a793ce255c3f6d19ae31e49b673af6c))
